@@ -1,11 +1,20 @@
 import boto3
+from dotenv import load_dotenv
+
+import os
 
 REG_FORM_QUEUE_NAME = "md410-conv-reg-form.fifo"
 REG_FORM_QUEUE_URL = (
     "https://sqs.af-south-1.amazonaws.com/960171457841/md410-conv-reg-form.fifo"
 )
 
-SESSION = boto3.Session(profile_name="md410-conv")
+
+load_dotenv()
+
+SESSION = boto3.Session(
+    aws_access_key_id=os.getenv("AWS_ACCESS_KEY_ID"),
+    aws_secret_access_key=os.getenv("AWS_SECRET_ACCESS_KEY"),
+)
 SQS = SESSION.resource(
     "sqs",
     region_name="af-south-1",
